==> kst_1.0.0.orig.tar.gz: kst-1.0.0/kst/kst/kstprintoptionspage.h <==
/***************************************************************************
                      kstprintoptionspage.h  -  Part of KST
                             -------------------
    begin                : Thu Sep 23 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _KST_POP_H
#define _KST_POP_H

class QCheckBox;
#include <kdeprint/kprintdialogpage.h>

class KstPrintOptionsPage : public KPrintDialogPage {
  public:
    KstPrintOptionsPage(QWidget *parent = 0L, const char *name = 0L);
    virtual ~KstPrintOptionsPage();

    void setOptions(const QMap<QString,QString>& opts);
    void getOptions(QMap<QString,QString>& opts, bool include_def = false);
    bool isValid(QString& msg);

  private:
    QCheckBox *_dateTimeFooter, *_bw;
    QSpinBox *_curveWidthAdjust;
};

#endif

// vim: ts=2 sw=2 et

==> kst-1.1.1.tar.gz: kst-1.1.1/kst/kst/kstprintoptionspage.h <==
/***************************************************************************
                      kstprintoptionspage.h  -  Part of KST
                             -------------------
    begin                : Thu Sep 23 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _KST_POP_H
#define _KST_POP_H

class QCheckBox;
#include <kdeprint/kprintdialogpage.h>

class KstPrintOptionsPage : public KPrintDialogPage {
  public:
    KstPrintOptionsPage(QWidget *parent = 0L, const char *name = 0L);
    virtual ~KstPrintOptionsPage();

    void setOptions(const QMap<QString,QString>& opts);
    void getOptions(QMap<QString,QString>& opts, bool include_def = false);
    bool isValid(QString& msg);

  private:
    QCheckBox *_dateTimeFooter;
    QCheckBox *_maintainAspectRatio;
    QCheckBox *_bw;
    QSpinBox *_curveWidthAdjust;
};

#endif

// vim: ts=2 sw=2 et
